# -*- coding: utf-8 -*-

from django import forms
from django.contrib import admin
from django.contrib.postgres.forms import JSONField
from django.utils.translation import ugettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class ThxEmailBackendAdminForm(forms.ModelForm):
    allowed_addresses = JSONField(
        required=False,
        help_text=_("addresses allowed to receives email from this backend"),  # always allowed?!
    )
    forbidden_addresses = JSONField(
        required=False,
        help_text=_("addresses not allowed to receives email from this backend"),
    )
    allowed_domains = JSONField(
        required=False,
        help_text=_("domains allowed to receives email from this backend"),
    )
    forbidden_domains = JSONField(
        required=False,
        help_text=_("domains not allowed to receives email from this backend"),
    )
    default_to_received_addresses = JSONField(
        required=False,
        help_text=_(
            "fill this field if you want that this addresses will always receives all emails that are sent as TO"
        ),
    )
    default_cc_received_addresses = JSONField(
        required=False,
        help_text=_(
            "fill this field if you want that this addresses will always receives all emails that are sent on CC"
        ),
    )
    default_bcc_received_addresses = JSONField(
        required=False,
        help_text=_(
            "fill this field if you want that this addresses will always receives all emails that are sent on BCC"
        ),
    )

    class Meta:
        fields = '__all__'
        model = models.ThxEmailBackend


class ThxEmailBackendAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    form = ThxEmailBackendAdminForm
    search_fields = ("name",)
    advanced_search_fields = (
        ("status", "name__iexact",),
        ("environment", "restraint_logic",),
        ("enable_loggers", "logger__iexact", "logger_level",),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': (
                ("status", "name",),
                ("environment", "restraint_logic",),
                ("allowed_addresses", "forbidden_addresses",),
                ("allowed_domains", "forbidden_domains",),
                ("default_to_received_addresses", "default_cc_received_addresses", "default_bcc_received_addresses",),
                ("enable_loggers", "logger", "logger_level",),
            )
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', )
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = (
        'pk', 'status',
        "name", "environment", "enable_loggers", "restraint_logic",
        'ordering'
    )
    list_display_links = ()
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.ThxEmailBackend, ThxEmailBackendAdmin)
